==> mingw-w64-thorvg-0.13.6-1.src.tar.zst: thorvg-0.13.6/src/renderer/gl_engine/tvgGlShader.h <==
/*
 * Copyright (c) 2020 - 2024 the ThorVG project. All rights reserved.

 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef _TVG_GL_SHADER_H_
#define _TVG_GL_SHADER_H_

#include "tvgGlCommon.h"

class GlShader
{
public:
    static std::shared_ptr<GlShader> gen(const char* vertSrc, const char* fragSrc);
    ~GlShader();

    uint32_t getVertexShader();
    uint32_t getFragmentShader();

private:
    void    createShader(const char* vertSrc, const char* fragSrc);
    uint32_t complileShader(uint32_t type, char* shaderSrc);

    uint32_t mVtShader;
    uint32_t mFrShader;
};

#endif /* _TVG_GL_SHADER_H_ */

==> mingw-w64-thorvg-0.15.13-1.src.tar.zst: thorvg-0.15.13/src/renderer/gl_engine/tvgGlShader.h <==
/*
 * Copyright (c) 2020 - 2024 the ThorVG project. All rights reserved.

 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef _TVG_GL_SHADER_H_
#define _TVG_GL_SHADER_H_

#include "tvgGlCommon.h"

class GlShader
{
public:
    static std::shared_ptr<GlShader> gen(const char* vertSrc, const char* fragSrc);
    ~GlShader();

    uint32_t getVertexShader();
    uint32_t getFragmentShader();

private:
    void    createShader(const char* vertSrc, const char* fragSrc);
    uint32_t compileShader(uint32_t type, char* shaderSrc);

    uint32_t mVtShader;
    uint32_t mFrShader;
};

#endif /* _TVG_GL_SHADER_H_ */
